from .utils.function import f

print('Welcome to Numerica!')

# Test
# ...